<?php
class IprimAPI
{
    protected $apiServer = 'http://iprim.ru/api';
    protected $apiKey;
    protected $apiNamespace = '';

    protected $_prepare = array();

    public function __construct($apiKey, $apiNamespace = '')
    {
        $this->apiKey = $apiKey;
        $this->apiNamespaace = $apiNamespace;
    }

    /**
     * @param array $options
     * @return array
     */
    public function getAll($options = array())
    {
        $path = '/';
        if($options) $path = array($path, http_build_query(array('options' => $options)));
        return $this->request($path);
    }

    /**
     * @param string|array $id
     * @param array $options
     * @return array
     */
    public function get($id, $options = array())
    {
        if(is_array($id)){
            $id = implode(',', $id);
        }
        $path = '/'.$id;
        if($options) $path = array($path, http_build_query(array('options' => $options)));
        return $this->request($path);
    }

    /**
     * @param array $data
     * @return $this
     */
    public function add($data)
    {
        $this->_prepare[] = $data;
        return $this;
    }

    /**
     * @return array
     * @throws Exception
     */
    public function save()
    {
        if(!$this->_prepare){
            throw new Exception('Ошибка запроса: нет данных. Перед тем как вызывать метод save, используйте метод add для добавления данных');
        }
        $data = $this->_prepare;
        $this->_prepare = array();
        return $this->request('/', 'post', $data);
    }

    /**
     * @param string|array $id
     * @return array
     */
    public function delete($id)
    {
        if(is_array($id)){
            $id = implode(',', $id);
        }
        return $this->request('/'.$id, 'delete');
    }
    
    /**
     * @param array $data
     * @return array
     */
    public function addCategory($data)
    {
        return $this->request('/category', 'post', $data);
    }
    
    /**
     * @param string|array $id
     * @return array
     */
    public function deleteCategory($id = [])
    {
        if(is_array($id)){
            $id = implode(',', $id);
        }
        return $this->request('/category/'.$id, 'delete');
    }

    /**
     * @param array|string $path
     * @param string $method
     * @param array $data
     * @return array|mixed
     */
    protected function request($path, $method = 'get', $data = array())
    {
        $params = '';
        if(is_array($path)){
            list($path, $params) = $path;
        }
        $url = rtrim($this->apiServer.$this->apiNamespaace.$path, '/').'.json?api_key='.$this->apiKey;
        if($params) $url .= '&'.$params;

        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_NOBODY, 			0);
        curl_setopt($ch, CURLOPT_HEADER, 			0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 	1);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT,  	30);
        curl_setopt($ch, CURLOPT_TIMEOUT, 			120);
        curl_setopt($ch, CURLOPT_ENCODING, 			'UTF-8');
        curl_setopt($ch, CURLOPT_USERAGENT, 		'IprimAPI/1.0');
        curl_setopt($ch, CURLOPT_REFERER,			'http://'.$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI']);

        $headers = array('Content-Type: application/json');

        if($data){
            $dataString = json_encode($data);
            $headers[] = 'Content-Length: ' . strlen($dataString);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);
        }
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

        if($method == 'post') curl_setopt($ch, CURLOPT_POST, true);
        elseif($method != 'get') curl_setopt($ch, CURLOPT_CUSTOMREQUEST, strtoupper($method));

		//$status 	= curl_getinfo($ch);
        $data 		= curl_exec($ch);
        curl_close($ch);
        
        //echo "<pre>   "  . print_r(  $status , true ) . "   </pre>";  
        //echo "<pre>   "  . print_r(  $data , true ) . "   </pre>";  

        $data = json_decode($data, true);
        return $data;
    }

    /**
     * @param $url
     * @return $this
     */
    public function setServer($url)
    {
        $this->apiServer = $url;
        return $this;
    }
}