<?php
// Подключаем библиотеку IprimAPI
require(__DIR__ . '/IprimAPI.php');

// Ключ доступа
$apiKey = 'my_api_key';

// Инициируем библиотеку
$api = new IprimAPI($apiKey, '/goods');

/*
 * Примеры использования
 */

/**
 * Получение всех товаров
 *
 * Результат:
 * ~~~
    {
        "items": {
            "585": {
                "id": "585",
                "code_number": "AB-23324-01",
                "name": "Toyota Hilux Surf",
                "description": "...",
                "price_prefix": "",
                "price": "0",
                "on_main_page": "1",
                "allow_basket": "1",
                "is_absent": "0",
                "hidden": "0",
                "photo": [
                    {
                        "original": "http://iprim.ru/images/goods/7404.png",
                        "small": "http://iprim.ru/images/goods/preview/c_7404.png"
                    }
                ]
            },
            "586": { ... },
            ...
        },
        "options": {
            "limit": 1,
            "skip": 20,
            "list": 0
        }
    }
 * ~~~
 */
$options = array( // Необязательный параметр
    'skip' => 10, // Пропустить результатов
    'limit' => 10, // Кол-во результатов
    'list' => 1 // Отображать как список (ключи по порядку с нуля)
);
$data = $api->getAll($options);

/**
 * Получение товара по артикулу (идентификатор товара в вашей базе данных)
 *
 * Результат:
 * ~~~
    {
        "data": {
            // Данные товара, как в методе getAll()
        },
        "conditions": {
            "code_number": [
                "AB-23324-01"
            ]
        }
    }
 * ~~~
 */
$codeNumber = 'AB-23324-01';
$data = $api->get($codeNumber);

/**
 * Получение нескольких товаров по артикулу
 *
 * Результат: как в методе getAll()
 */
$codeNumber = array('AB-14565-24', 'AB-14566-24', 'AB-14567-24');
$options = array('list' => 0); // как в методе getAll()
$data = $api->get($codeNumber, $options);

/**
 * Добавление и обновление товара на IPRIM.RU
 * Для иденитификации товаров используется артикул
 * Если товара нет, он будет создан, иначе - обновлен
 *
 * При добавлении обязательные поля: name и code_number
 * При редактировании: code_number и хотя бы одно из редактируемых полей
 *
 * Результат:
 * Параметры запроса + 2 поля:
 *      result - содержит либо 1, либо 0 в зависимости от успешности операции
 *      id - ID товара на IPRIM.RU
 *
 * В случае ошибки также добавляется поле error с описанием ошибки
 * ~~~
 */
$data = array(
    "code_number" => "AB-23324-01",
    "name" => "Toyota Hilux Surf",
    "description" => "<b>Двигатель:</b> дизель, 3000 куб.см<br />
				<b>Трансмиссия:</b> автомат<br />
				<b>Привод:</b> 4WD<br />
				<b>Пробег по России:</b> есть<br />
				<b>Пробег, км:</b> 210000<br />
				<b>Руль:</b> правый<br />
				<b>Дополнительно:</b> Продам хороший SURF. 					Таможенный ПТС. 2 хозяина.",
    "price_prefix" => "",
    "price" => "0",
    "on_main_page" => "1",
    "allow_basket" => "1",
    "is_absent" => "0",
    "hidden" => "0",
    "photo" => array(
        "http://mysite.ru/path/to/image1.png",
        "http://mysite.ru/path/to/image2.png"
    )
);

$api->add($data);
$api->save();

// Чтобы отправить несколько товаров,
// необходимо вызвать метод add для каждого из товаров
$api->add(array('code_number' => 123, 'name' => 'Товар 123'));
$api->add(array('code_number' => 124, 'name' => 'Товар 124'));
$api->save();

// Чтобы загрузить фото товара,
// надо передать его абсолютный url в параметре photo
$api->add(array(
        'code_number' => 123,
        'name' => 'Товар 123',
        'photo' => 'http://mysite.ru/images/photo_123.png'
    ));
$api->save();

// Чтобы загрузить несколько фото,
// передайте cписок url
$api->add(array(
        'code_number' => 123,
        'name' => 'Товар 123',
        'photo' => array(
            'http://mysite.ru/images/photo_123_1.png',
            'http://mysite.ru/images/photo_123_2.png',
            'http://mysite.ru/images/photo_123_3.png'
        )
    ));
$api->save();

// ПРИМЕРЫ РЕДАКТИРОВАНИЯ:
$codeNumber = 'AB-14565-24';
$api->add(array('code_number' => $codeNumber, 'is_absent' => 1))->save(); // Товар закончился
$api->add(array('code_number' => $codeNumber, 'is_absent' => 0))->save(); // Товар появился
$api->add(array('code_number' => $codeNumber, 'hidden' => 1))->save(); // Скрыть товар
$api->add(array('code_number' => $codeNumber, 'hidden' => 0))->save(); // Показать товар

/**
 * Удаление товара по артикулу
 * Возвращает кол-во удаленных товаров
 */
$codeNumber = '175';
$countDeleted = $api->delete($codeNumber);

/**
 * Удаление нескольких товаров по артикулу
 */
$codeNumber = array('AB-14565-24', 'AB-14566-24', 'AB-14567-24');
$countDeleted = $api->delete($codeNumber);